==> medlogics-common-classes-1.1-20250512.073739-1.jar: com/floreantpos/model/dao/NurseVisitDAO.java <==
package com.floreantpos.model.dao;

import java.io.Serializable;

import org.apache.commons.lang.StringUtils;
import org.hibernate.Criteria;
import org.hibernate.Session;
import org.hibernate.criterion.Order;
import org.hibernate.criterion.Restrictions;

import com.floreantpos.model.NurseVisit;
import com.floreantpos.model.PatientBookingStatus;
import com.floreantpos.swing.PaginatedListModel;

public class NurseVisitDAO extends BaseNurseVisitDAO {

	@Override
	protected Serializable save(Object obj, Session s) {
		updateTime(obj);
		return super.save(obj, s);
	}

	@Override
	protected void update(Object obj, Session s) {
		updateTime(obj);
		super.update(obj, s);
	}

	@Override
	protected void delete(Object obj, Session s) {
		NurseVisit nurseVisit = (NurseVisit) obj;
		nurseVisit.setDeleted(true);
		update(nurseVisit, s);
	}

	@Override
	protected void saveOrUpdate(Object obj, Session s) {
		updateTime(obj);
		super.saveOrUpdate(obj, s);
	}

	public void loadNurseVisit(PaginatedListModel<NurseVisit> dataModel, String patientId, String roomId, String bedId) {
		try (Session session = createNewSession()) {
			Criteria criteria = session.createCriteria(NurseVisit.class);
			addDeletedFilter(criteria);

			if (StringUtils.isNotBlank(patientId)) {
				criteria.add(Restrictions.eq(NurseVisit.PROP_PATIENT_ID, patientId));
			}

			DoctorVisitDAO.createRoomAndBedCriteria(roomId, bedId, criteria, NurseVisit.PROP_ADMISSION_ID, PatientBookingStatus.ACTIVE);

			dataModel.setNumRows(rowCount(criteria));

			criteria.addOrder(Order.desc(NurseVisit.PROP_CREATED_DATE));
			criteria.setFirstResult(dataModel.getCurrentRowIndex());
			criteria.setMaxResults(dataModel.getPageSize());
			dataModel.setData(criteria.list());
		}

	}

	public NurseVisit getLastNurseVisit(String bookingId) {
		if (StringUtils.isBlank(bookingId)) {
			return null;
		}
		try (Session session = createNewSession()) {
			Criteria criteria = session.createCriteria(NurseVisit.class);
			addDeletedFilter(criteria);
			criteria.add(Restrictions.eq(NurseVisit.PROP_ADMISSION_ID, bookingId));
			criteria.addOrder(Order.desc(NurseVisit.PROP_CREATED_DATE));
			criteria.setMaxResults(1);
			return (NurseVisit) criteria.uniqueResult();
		}
	}

}

==> medlogics-common-classes-1.1-20250521.161153-49.jar: com/floreantpos/model/dao/NurseVisitDAO.java <==
package com.floreantpos.model.dao;

import java.io.Serializable;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.hibernate.Criteria;
import org.hibernate.Session;
import org.hibernate.criterion.Order;
import org.hibernate.criterion.Restrictions;

import com.floreantpos.model.NurseVisit;
import com.floreantpos.model.PatientBookingStatus;
import com.floreantpos.swing.PaginatedListModel;

public class NurseVisitDAO extends BaseNurseVisitDAO {

	@Override
	protected Serializable save(Object obj, Session s) {
		updateTime(obj);
		return super.save(obj, s);
	}

	@Override
	protected void update(Object obj, Session s) {
		updateTime(obj);
		super.update(obj, s);
	}

	@Override
	protected void delete(Object obj, Session s) {
		NurseVisit nurseVisit = (NurseVisit) obj;
		nurseVisit.setDeleted(true);
		update(nurseVisit, s);
	}

	@Override
	protected void saveOrUpdate(Object obj, Session s) {
		updateTime(obj);
		super.saveOrUpdate(obj, s);
	}

	public void loadNurseVisit(PaginatedListModel<NurseVisit> dataModel, String patientId, String roomId, String bedId) {
		try (Session session = createNewSession()) {
			Criteria criteria = session.createCriteria(NurseVisit.class);
			addDeletedFilter(criteria);

			if (StringUtils.isNotBlank(patientId)) {
				criteria.add(Restrictions.eq(NurseVisit.PROP_PATIENT_ID, patientId));
			}

			DoctorVisitDAO.createRoomAndBedCriteria(roomId, bedId, criteria, NurseVisit.PROP_ADMISSION_ID, PatientBookingStatus.ACTIVE);

			dataModel.setNumRows(rowCount(criteria));

			criteria.addOrder(Order.desc(NurseVisit.PROP_CREATED_DATE));
			criteria.setFirstResult(dataModel.getCurrentRowIndex());
			criteria.setMaxResults(dataModel.getPageSize());
			dataModel.setData(criteria.list());
		}

	}

	public NurseVisit getLastNurseVisit(String bookingId) {
		if (StringUtils.isBlank(bookingId)) {
			return null;
		}
		try (Session session = createNewSession()) {
			Criteria criteria = session.createCriteria(NurseVisit.class);
			addDeletedFilter(criteria);
			criteria.add(Restrictions.eq(NurseVisit.PROP_ADMISSION_ID, bookingId));
			criteria.addOrder(Order.desc(NurseVisit.PROP_CREATED_DATE));
			criteria.setMaxResults(1);
			return (NurseVisit) criteria.uniqueResult();
		}
	}

	public List<NurseVisit> getLatestNurseVisits(String bookingId, int maxResult) {
		if (StringUtils.isBlank(bookingId)) {
			return null;
		}
		try (Session session = createNewSession()) {
			Criteria criteria = session.createCriteria(NurseVisit.class);
			addDeletedFilter(criteria);
			criteria.add(Restrictions.eq(NurseVisit.PROP_ADMISSION_ID, bookingId));
			criteria.setMaxResults(maxResult);
			criteria.addOrder(Order.desc(NurseVisit.PROP_CREATED_DATE));
			return criteria.list();
		}
	}

}
